@@ -3,15 +3,7 @@
 // rustdoc-stripper-ignore-next
 //! Traits intended for blanket imports.
 
-pub use crate::auto::traits::*;
-
-pub use crate::renderer::RendererExtManual;
-
 #[doc(hidden)]
 pub use gdk::prelude::*;
-#[doc(hidden)]
-pub use glib::prelude::*;
-#[doc(hidden)]
-pub use graphene::prelude::*;
-#[doc(hidden)]
-pub use pango::prelude::*;
+
+pub use crate::{auto::traits::*, render_node::IsRenderNode};
